@@ -1,41 +1,48 @@
-/*===========================================================================*\
-*                                                                           *
-*                               OpenMesh                                    *
-*      Copyright (C) 2001-2014 by Computer Graphics Group, RWTH Aachen      *
-*                           www.openmesh.org                                *
-*                                                                           *
-*---------------------------------------------------------------------------*
-*  This file is part of OpenMesh.                                           *
-*                                                                           *
-*  OpenMesh is free software: you can redistribute it and/or modify         *
-*  it under the terms of the GNU Lesser General Public License as           *
-*  published by the Free Software Foundation, either version 3 of           *
-*  the License, or (at your option) any later version with the              *
-*  following exceptions:                                                    *
-*                                                                           *
-*  If other files instantiate templates or use macros                       *
-*  or inline functions from this file, or you compile this file and         *
-*  link it with other files to produce an executable, this file does        *
-*  not by itself cause the resulting executable to be covered by the        *
-*  GNU Lesser General Public License. This exception does not however       *
-*  invalidate any other reasons why the executable file might be            *
-*  covered by the GNU Lesser General Public License.                        *
-*                                                                           *
-*  OpenMesh is distributed in the hope that it will be useful,              *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of           *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
-*  GNU Lesser General Public License for more details.                      *
-*                                                                           *
-*  You should have received a copy of the GNU LesserGeneral Public          *
-*  License along with OpenMesh.  If not,                                    *
-*  see <http://www.gnu.org/licenses/>.                                      *
-*                                                                           *
-\*===========================================================================*/
+/* ========================================================================= *
+ *                                                                           *
+ *                               OpenMesh                                    *
+ *           Copyright (c) 2001-2015, RWTH-Aachen University                 *
+ *           Department of Computer Graphics and Multimedia                  *
+ *                          All rights reserved.                             *
+ *                            www.openmesh.org                               *
+ *                                                                           *
+ *---------------------------------------------------------------------------*
+ * This file is part of OpenMesh.                                            *
+ *---------------------------------------------------------------------------*
+ *                                                                           *
+ * Redistribution and use in source and binary forms, with or without        *
+ * modification, are permitted provided that the following conditions        *
+ * are met:                                                                  *
+ *                                                                           *
+ * 1. Redistributions of source code must retain the above copyright notice, *
+ *    this list of conditions and the following disclaimer.                  *
+ *                                                                           *
+ * 2. Redistributions in binary form must reproduce the above copyright      *
+ *    notice, this list of conditions and the following disclaimer in the    *
+ *    documentation and/or other materials provided with the distribution.   *
+ *                                                                           *
+ * 3. Neither the name of the copyright holder nor the names of its          *
+ *    contributors may be used to endorse or promote products derived from   *
+ *    this software without specific prior written permission.               *
+ *                                                                           *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       *
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED *
+ * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A           *
+ * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER *
+ * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,  *
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,       *
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR        *
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF    *
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING      *
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS        *
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.              *
+ *                                                                           *
+ * ========================================================================= */
 
 /*===========================================================================*\
 *                                                                           *
-*   $Revision: 990 $                                                         *
-*   $Date: 2014-02-05 10:01:07 +0100 (Mi, 05 Feb 2014) $                   *
+*   $Revision: 1258 $                                                         *
+*   $Date: 2015-04-28 15:07:46 +0200 (Di, 28 Apr 2015) $                   *
 *                                                                           *
 \*===========================================================================*/
 
@@ -92,6 +99,11 @@ size_t MixedDecimaterT<Mesh>::decimate(const size_t _n_collapses, const float _m
   size_t r_collapses = 0;
   if (_mc_factor > 0.0)
     r_collapses = McDecimaterT<Mesh>::decimate(n_collapses_mc);
+
+  // returns, if the previous steps were aborted by the observer
+  if (this->observer() && this->observer()->abort())
+      return r_collapses;
+
   if (_mc_factor < 1.0)
     r_collapses += DecimaterT<Mesh>::decimate(n_collapses_inc);
 
@@ -147,6 +159,10 @@ size_t MixedDecimaterT<Mesh>::decimate_to_faces(const size_t  _n_vertices,const
   //Update the mesh::n_vertices function, otherwise the next Decimater function will delete too much
   this->mesh().garbage_collection();
 
+  // returns, if the previous steps were aborted by the observer
+  if (this->observer() && this->observer()->abort())
+      return r_collapses;
+
   //reduce the rest of the mesh
   if (_mc_factor < 1.0) {
     r_collapses += DecimaterT<Mesh>::decimate_to_faces(_n_vertices,_n_faces);
